@@ -36,11 +36,12 @@ struct icon_pair {
 #define COLOR_REACT        39  /* DeepSkyBlue1 */
 #define COLOR_CSS          199 /* DeepPink1 */
 #define COLOR_PYTHON       227 /* LightGoldenrod1 */
-#define COLOR_LUA          19  /* LightGoldenrod1 */
-#define COLOR_DOCUMENT     15  /* WHITE */
+#define COLOR_LUA          19  /* Blue3 */
+#define COLOR_DOCUMENT     15  /* White */
 #define COLOR_FSHARP       31  /* DeepSkyBlue3 */
 #define COLOR_RUBY         160 /* Red3 */
 #define COLOR_SCALA        196 /* Red1 */
+#define COLOR_SHELL        47  /* SpringGreen2 */
 #define COLOR_VIM          28  /* Green4 */
 
 /*
@@ -180,7 +181,7 @@ static const struct icon_pair icons_ext[] = {
 
 	/* I */
 	{"ico",      FA_FILE_IMAGE_O,      COLOR_IMAGE},
-	{"img",      FA_FILE_ARCHIVE_O,    COLOR_ARCHIVE},
+	{"img",      LINEA_MUSIC_CD,       COLOR_ARCHIVE},
 	{"ini",      FA_COGS,              0},
 	{"iso",      LINEA_MUSIC_CD,       COLOR_ARCHIVE},
 
@@ -199,7 +200,7 @@ static const struct icon_pair icons_ext[] = {
 	/* L */
 	{"lha",      FA_FILE_ARCHIVE_O,    COLOR_ARCHIVE},
 	{"log",      FA_FILE_TEXT_O,       0},
-	{"lua",      FILE_LUA,             0},
+	{"lua",      FILE_LUA,             COLOR_LUA},
 	{"lzh",      FA_FILE_ARCHIVE_O,    COLOR_ARCHIVE},
 	{"lzma",     FA_FILE_ARCHIVE_O,    COLOR_ARCHIVE},
 
@@ -244,6 +245,7 @@ static const struct icon_pair icons_ext[] = {
 
 	/* R */
 	{"rar",      FA_FILE_ARCHIVE_O,    COLOR_ARCHIVE},
+	{"rb",       MFIZZ_RUBY,           COLOR_RUBY},
 	{"rc",       FA_COGS,              0},
 	{"rom",      FA_LOCK,              0},
 	{"rpm",      FA_FILE_ARCHIVE_O,    COLOR_ARCHIVE},
@@ -253,7 +255,7 @@ static const struct icon_pair icons_ext[] = {
 	/* S */
 	{"so",       FILE_MANPAGE,         0},
 	{"scala",    MFIZZ_SCALA,          0},
-	{"sh",       MFIZZ_SCRIPT,         0},
+	{"sh",       MFIZZ_SCRIPT,         COLOR_SHELL},
 	{"slim",     FA_FILE_CODE_O,       0},
 	{"sln",      DEV_VISUALSTUDIO,     0},
 	{"sql",      MFIZZ_MYSQL,          0},
@@ -286,6 +288,7 @@ static const struct icon_pair icons_ext[] = {
 
 	/* X */
 	{"xbps",     FA_FILE_ARCHIVE_O,    COLOR_ARCHIVE},
+	{"xcf",      FA_FILE_IMAGE_O,      COLOR_IMAGE},
 	{"xhtml",    FA_FILE_CODE_O,       0},
 	{"xls",      FILE_EXCEL,           0},
 	{"xlsx",     FILE_EXCEL,           0},
@@ -314,6 +317,7 @@ static const struct icon_pair icons_ext[] = {
 
 	/* B */
 	{"bat",        ICON_EXT_BAT,       0},
+	{"bib",        ICON_EXT_BIB,       0},
 	{"bin",        ICON_EXT_BIN,       0},
 	{"bmp",        ICON_EXT_BMP,       COLOR_IMAGE},
 	{"bz2",        ICON_EXT_BZ2,       COLOR_ARCHIVE},
@@ -321,6 +325,7 @@ static const struct icon_pair icons_ext[] = {
 	 /* C */
 	{"c",          ICON_EXT_C,         COLOR_C},
 	{"c++",        ICON_EXT_CPLUSPLUS, COLOR_C},
+	{"cabal",      ICON_EXT_CABAL,     COLOR_VIDEO},
 	{"cab",        ICON_EXT_CAB,       COLOR_ARCHIVE},
 	{"cbr",        ICON_EXT_CBR,       COLOR_ARCHIVE},
 	{"cbz",        ICON_EXT_CBZ,       COLOR_ARCHIVE},
@@ -329,11 +334,12 @@ static const struct icon_pair icons_ext[] = {
 	{"clj",        ICON_EXT_CLJ,       0},
 	{"cljc",       ICON_EXT_CLJC,      0},
 	{"cljs",       ICON_EXT_CLJS,      0},
+	{"cls",        ICON_EXT_CLS,       0},
 	{"cmake",      ICON_EXT_CMAKE,     0},
 	{"coffee",     ICON_EXT_COFFEE,    0},
 	{"conf",       ICON_EXT_CONF,      0},
 	{"cpio",       ICON_EXT_CPIO,      COLOR_ARCHIVE},
-	{"cpp",        ICON_EXT_CPP,       0},
+	{"cpp",        ICON_EXT_CPP,       COLOR_C},
 	{"css",        ICON_EXT_CSS,       COLOR_CSS},
 	{"cue",        ICON_EXT_CUE,       COLOR_AUDIO},
 	{"cvs",        ICON_EXT_CVS,       0},
@@ -355,6 +361,7 @@ static const struct icon_pair icons_ext[] = {
 
 	/* F */
 	{"f#",         ICON_EXT_FSHARP,    COLOR_FSHARP},
+	{"fen",        ICON_EXT_FEN,       0},
 	{"flac",       ICON_EXT_FLAC,      COLOR_AUDIO},
 	{"flv",        ICON_EXT_FLV,       COLOR_VIDEO},
 	{"fs",         ICON_EXT_FS,        COLOR_FSHARP},
@@ -372,6 +379,8 @@ static const struct icon_pair icons_ext[] = {
 	/* H */
 	{"h",          ICON_EXT_H,         COLOR_C},
 	{"hh",         ICON_EXT_HH,        COLOR_C},
+	{"hpp",        ICON_EXT_HPP,       COLOR_C},
+	{"hs",         ICON_EXT_HS,        COLOR_VIM},
 	{"htaccess",   ICON_EXT_HTACCESS,  0},
 	{"htpasswd",   ICON_EXT_HTPASSWD,  0},
 	{"htm",        ICON_EXT_HTM,       0},
@@ -398,15 +407,18 @@ static const struct icon_pair icons_ext[] = {
 
 	/* L */
 	{"lha",        ICON_EXT_LHA,       COLOR_ARCHIVE},
+	{"lhs",        ICON_EXT_LHS,       COLOR_VIM},
 	{"log",        ICON_EXT_LOG,       0},
-	{"lua",        ICON_EXT_LUA,       0},
+	{"lua",        ICON_EXT_LUA,       COLOR_LUA},
 	{"lzh",        ICON_EXT_LZH,       COLOR_ARCHIVE},
 	{"lzma",       ICON_EXT_LZMA,      COLOR_ARCHIVE},
 
 	/* M */
+	{"m",          ICON_EXT_M,         COLOR_C},
 	{"m4a",        ICON_EXT_M4A,       COLOR_AUDIO},
 	{"m4v",        ICON_EXT_M4V,       COLOR_VIDEO},
 	{"markdown",   ICON_EXT_MD,        COLOR_DOCS},
+	{"mat",        ICON_EXT_MAT,       COLOR_C},
 	{"md",         ICON_EXT_MD,        COLOR_DOCS},
 	{"mk",         ICON_EXT_MK,        0},
 	{"mkv",        ICON_EXT_MKV,       COLOR_VIDEO},
@@ -418,6 +430,7 @@ static const struct icon_pair icons_ext[] = {
 	{"msi",        ICON_EXT_MSI,       0},
 
 	/* N */
+	{"nix",        ICON_EXT_NIX,       COLOR_FSHARP},
 
 	/* O */
 	{"o",          ICON_EXT_O,         0},
@@ -429,6 +442,7 @@ static const struct icon_pair icons_ext[] = {
 	{"part",       ICON_EXT_PART,      0},
 	{"patch",      ICON_EXT_PATCH,     0},
 	{"pdf",        ICON_EXT_PDF,       COLOR_DOCS},
+	{"pgn",        ICON_EXT_PGN,       0},
 	{"php",        ICON_EXT_PHP,       0},
 	{"png",        ICON_EXT_PNG,       COLOR_IMAGE},
 	{"ppt",        ICON_EXT_PPT,       0},
@@ -444,6 +458,7 @@ static const struct icon_pair icons_ext[] = {
 
 	/* R */
 	{"rar",        ICON_EXT_RAR,       COLOR_ARCHIVE},
+	{"rb",         ICON_EXT_RB,        COLOR_RUBY},
 	{"rc",         ICON_EXT_RC,        0},
 	{"rom",        ICON_EXT_ROM,       0},
 	{"rpm",        ICON_EXT_RPM,       COLOR_ARCHIVE},
@@ -455,11 +470,12 @@ static const struct icon_pair icons_ext[] = {
 	{"scss",       ICON_EXT_SCSS,      COLOR_CSS},
 	{"so",         ICON_EXT_SO,        0},
 	{"scala",      ICON_EXT_SCALA,     COLOR_SCALA},
-	{"sh",         ICON_EXT_SH,        0},
+	{"sh",         ICON_EXT_SH,        COLOR_SHELL},
 	{"slim",       ICON_EXT_SLIM,      COLOR_DOCUMENT},
 	{"sln",        ICON_EXT_SLN,       0},
 	{"sql",        ICON_EXT_SQL,       0},
 	{"srt",        ICON_EXT_SRT,       0},
+	{"sty",        ICON_EXT_STY,       0},
 	{"sub",        ICON_EXT_SUB,       0},
 	{"svg",        ICON_EXT_SVG,       COLOR_IMAGE},
 
@@ -488,6 +504,7 @@ static const struct icon_pair icons_ext[] = {
 
 	/* X */
 	{"xbps",       ICON_EXT_XBPS,      COLOR_ARCHIVE},
+	{"xcf",        ICON_EXT_XCF,       COLOR_IMAGE},
 	{"xhtml",      ICON_EXT_XHTML,     0},
 	{"xls",        ICON_EXT_XLS,       0},
 	{"xlsx",       ICON_EXT_XLSX,      0},
@@ -500,6 +517,8 @@ static const struct icon_pair icons_ext[] = {
 
 	/* Z */
 	{"zip",        ICON_EXT_ZIP,       COLOR_ARCHIVE},
+	{"zsh",        ICON_EXT_ZSH,       COLOR_SHELL},
+	{"zst",        ICON_EXT_ZST,       COLOR_ARCHIVE},
 
 	/* Other */
 #endif
