@@ -60,7 +60,7 @@ enum action {
 	SEL_CDBEGIN,
 	SEL_CDLAST,
 	SEL_CDROOT,
-	SEL_BOOKMARK,
+	SEL_BMOPEN,
 	SEL_REMOTE,
 	SEL_CYCLE,
 	SEL_CYCLER,
@@ -75,6 +75,7 @@ enum action {
 	SEL_CTX8,
 #endif
 	SEL_MARK,
+	SEL_BMARK,
 	SEL_FLTR,
 	SEL_MFLTR,
 	SEL_HIDDEN,
@@ -104,7 +105,7 @@ enum action {
 	SEL_PLUGIN,
 	SEL_SHELL,
 	SEL_LAUNCH,
-	SEL_RUNCMD,
+	SEL_PROMPT,
 	SEL_LOCK,
 	SEL_SESSIONS,
 	SEL_EXPORT,
@@ -167,8 +168,8 @@ static struct key bindings[] = {
 	/* Go to / */
 	{ '`',            SEL_CDROOT },
 	/* Leader key */
-	{ 'b',            SEL_BOOKMARK },
-	{ CONTROL('_'),   SEL_BOOKMARK },
+	{ 'b',            SEL_BMOPEN },
+	{ CONTROL('_'),   SEL_BMOPEN },
 	/* Connect to server over SSHFS */
 	{ 'c',            SEL_REMOTE },
 	/* Cycle contexts in forward direction */
@@ -188,6 +189,8 @@ static struct key bindings[] = {
 #endif
 	/* Mark a path to visit later */
 	{ ',',            SEL_MARK },
+	/* Create a bookmark */
+	{ 'B',            SEL_BMARK },
 	/* Filter */
 	{ '/',            SEL_FLTR },
 	/* Toggle filter mode */
@@ -213,7 +216,6 @@ static struct key bindings[] = {
 	{ ' ',            SEL_SEL },
 	/* Toggle select multiple files */
 	{ 'm',            SEL_SELMUL },
-	{ CONTROL(' '),   SEL_SELMUL },
 	/* Select all files in current dir */
 	{ 'a',            SEL_SELALL },
 	/* Invert selection in current dir */
@@ -256,8 +258,8 @@ static struct key bindings[] = {
 	{ CONTROL(']'),   SEL_SHELL },
 	/* Launcher */
 	{ '=',            SEL_LAUNCH },
-	/* Run a command */
-	{ ']',            SEL_RUNCMD },
+	/* Show command prompt */
+	{ ']',            SEL_PROMPT },
 	/* Lock screen */
 	{ '0',            SEL_LOCK },
 	/* Manage sessions */
